"use client";

import {
  useReactTable,
  getCoreRowModel,
  flexRender,
} from "@tanstack/react-table";
import global from "/src/theme/global/global.module.scss";
import styles from "./TanStackTable.module.scss";
import { useEffect, useState } from "react";
import ReviewModal from "../reviewModal/ReviewModal";
import ArrowDropUpIcon from "@mui/icons-material/ArrowDropUp";
import ArrowDropDownIcon from "@mui/icons-material/ArrowDropDown";
import HeightIcon from "@mui/icons-material/Height";
import RemoveRedEyeIcon from "@mui/icons-material/RemoveRedEye";
import { IconButton, Tooltip } from "@mui/material";
import { grey } from "@mui/material/colors";

const TanStackTable = ({ data }: any) => {
  const [tableData, setTableData] = useState([]);
  const [open, setOpen] = useState(false);
  const [reviewModalData, setReviewModalData] = useState([]);
  const [sortOrder, setSortOrder] = useState<"asc" | "desc" | null>(null);
  const handleOpen = () => setOpen(true);
  const handleClose = () => setOpen(false);

  const handleSort = (key: string) => {
    let sortedData;
    if (sortOrder === "asc") {
      sortedData = [...tableData].sort((a, b) => (a[key] > b[key] ? -1 : 1));
      setSortOrder("desc");
    } else {
      sortedData = [...tableData].sort((a, b) => (a[key] > b[key] ? 1 : -1));
      setSortOrder("asc");
    }
    setTableData(sortedData);
  };

  /** Set Title and api data object key for the Table title and data */
  const columns: any = [
    {
      header: (
        <div className={styles.sort} onClick={() => handleSort("id")}>
          ID{" "}
          {sortOrder === "asc" ? (
            <ArrowDropUpIcon sx={{ color: grey[300] }} />
          ) : sortOrder === "desc" ? (
            <ArrowDropDownIcon sx={{ color: grey[300] }} />
          ) : (
            <HeightIcon sx={{ color: grey[300] }} />
          )}
        </div>
      ),
      accessorKey: "id",
    },
    {
      header: "Title",
      accessorKey: "title",
    },
    {
      header: "Description",
      accessorKey: "description",
      cell: ({ row }: any) => (
        <>
          <Tooltip title={row.original.description}>
            <p className={styles.clamp_2}>{row.original.description}</p>
          </Tooltip>
        </>
      ),
    },
    {
      header: "Category",
      accessorKey: "category",
    },
    {
      header: "Price",
      accessorKey: "price",
    },
    {
      header: "Discount Percentage",
      accessorKey: "discountPercentage",
    },
    {
      header: "Rating",
      accessorKey: "rating",
    },
    {
      header: "Stock",
      accessorKey: "stock",
    },
    {
      header: "Tags",
      accessorKey: "tags",
    },
    {
      header: "Brand",
      accessorKey: "brand",
    },
    {
      header: "Reviews",
      accessorKey: "reviews",
      cell: ({ row }: any) => (
        <>
          {/* {row.original.reviews.length} Reviews */}
          <IconButton
            aria-label="log out"
            size="medium"
            color="primary"
            onClick={() => handleButtonClick(row.original)}
          >
            <RemoveRedEyeIcon fontSize="small" />
          </IconButton>
        </>
      ),
    },
  ];

  /** Send Review array to Review Modal before openning */
  const handleButtonClick = (rowData: any) => {
    setReviewModalData(rowData?.reviews);
    handleOpen();
    // console.log("Button clicked for row:", rowData?.reviews);
  };

  const table = useReactTable({
    data: tableData,
    columns,
    getCoreRowModel: getCoreRowModel(),
  });

  useEffect(() => {
    setTableData(data?.products);
    console.log("Server data", data);
  }, [data]);

  return (
    <>
      <div className={styles.responsive_table}>
        <table className={styles.table}>
          <thead>
            {table.getHeaderGroups().map((headerGroup: any) => (
              <tr key={headerGroup?.id}>
                {headerGroup.headers.map((header: any) => (
                  <th key={header?.id} className={global.body2}>
                    {flexRender(
                      header.column.columnDef.header,
                      header.getContext()
                    )}
                  </th>
                ))}
              </tr>
            ))}
          </thead>
          <tbody>
            {table.getRowModel().rows.map((row: any) => (
              <tr key={row.id}>
                {row.getVisibleCells().map((cell: any) => (
                  <td key={cell.id}>
                    {flexRender(cell.column.columnDef.cell, cell.getContext())}
                  </td>
                ))}
              </tr>
            ))}
          </tbody>
        </table>
      </div>
      <ReviewModal
        open={open}
        handleClose={handleClose}
        reviewModalData={reviewModalData}
      />
    </>
  );
};

export default TanStackTable;
