"use client"; // This ensures the file is a client component
import * as React from "react";
import AppBar, { AppBarProps } from "@mui/material/AppBar";
import Box from "@mui/material/Box";
import CssBaseline from "@mui/material/CssBaseline";
import Drawer from "@mui/material/Drawer";
import IconButton from "@mui/material/IconButton";
import Avatar from "@mui/material/Avatar";
import List from "@mui/material/List";
import ListItem from "@mui/material/ListItem";
import ListItemButton from "@mui/material/ListItemButton";
import ListItemIcon from "@mui/material/ListItemIcon";
import ListItemText from "@mui/material/ListItemText";
import MenuIcon from "@mui/icons-material/Menu";
import Toolbar from "@mui/material/Toolbar";
import Typography from "@mui/material/Typography";
import { useState } from "react";
import { UTILITY_CONSTANT } from "@/utilities/utilityConstant";
import styles from "./DashboardWrapper.module.scss";
import styled from "@emotion/styled";
import { BUILDING, GEAR } from "@/utilities/svgConstant";
import LogoutIcon from "@mui/icons-material/Logout";
import { useRouter } from "next/navigation";

const drawerWidth = 260;

const CssList = styled(List)({
  width: "100%",
  paddingBlock: "24px",
  "& .MuiListItem-root": {
    "& .MuiButtonBase-root": {
      borderRadius: "15px",
      "& .MuiListItemIcon-root": {
        minWidth: "34px",
      },
      "&:hover": {
        backgroundColor: "var(--primary_light)",
        color: "var(--primary_Active_text)",

        "& .MuiListItemIcon-root": {
          color: "var(--primary_Active_text)",
        },
      },
    },
    "&.Mui-selected": {
      backgroundColor: "transparent",
      "& .MuiButtonBase-root": {
        backgroundColor: "var(--primary_light)",
        color: "var(--primary_Active_text)",
        "& .MuiListItemIcon-root": {
          color: "var(--primary_Active_text)",
        },
      },
    },
  },
});

const CssAppBar = styled(AppBar)<AppBarProps>({
  boxShadow: "none",
  backgroundColor: "var(--bg_white)",
  color: "var(--primary_text_clr)",
  "& .MuiToolbar-root": {
    minHeight: "72px",
  },
});

interface Props {
  window?: () => Window;
  children: React.ReactNode;
}

export default function DashboardWrapper(props: Props) {
  const { window } = props;
  const { children: Children } = props;
  const [mobileOpen, setMobileOpen] = useState(false);
  const [isClosing, setIsClosing] = useState(false);
  const router = useRouter()
  const handleDrawerClose = () => {
    setIsClosing(true);
    setMobileOpen(false);
  };

  const handleDrawerTransitionEnd = () => {
    setIsClosing(false);
  };

  const handleDrawerToggle = () => {
    if (!isClosing) {
      setMobileOpen(!mobileOpen);
    }
  };
  const [activeIndex, setActiveIndex] = useState<number | null>(null);

  const drawer = (
    <>
      <Toolbar sx={{ minHeight: "72px !important" }}>
        <img
          src={UTILITY_CONSTANT.IMAGES.AUTH.HEADER_LOG}
          alt="Logo"
          className={styles.logo}
        />
      </Toolbar>
      {/* <Divider /> */}
      <CssList sx={{ padding: "0", paddingInline: "18px" }}>
        {["Product Table"].map((text, index) => (
          <ListItem
            key={text}
            disablePadding
            selected={activeIndex === index} // Add this line to make the item "active"
            onClick={() => setActiveIndex(index)} // Add this line to handle click events
          >
            <ListItemButton>
              <ListItemIcon>
                {index % 2 === 0 ? <BUILDING /> : <BUILDING />}
              </ListItemIcon>
              <ListItemText primary={text} />
            </ListItemButton>
          </ListItem>
        ))}
      </CssList>
    </>
  );

  const container =
    window !== undefined ? () => window().document.body : undefined;

  const logoutHandler = () => {
    localStorage.removeItem('token');
    localStorage.removeItem('refreshToken');
    router.push('/log-in');
  }

  return (
    <Box
      sx={{ display: "flex" }}
      width={"100%"}
      height={"100%"}
      className={styles.dashboard_main}
    >
      <CssBaseline />
      <CssAppBar
        position="fixed"
        sx={{
          width: { md: `calc(100% - ${drawerWidth}px)` },
          ml: { md: `${drawerWidth}px` },
        }}
      >
        <Toolbar sx={{ width: "100%", justifyContent: "space-between" }}>
          <Box display={"flex"} alignItems={"center"}>
            <IconButton
              color="inherit"
              aria-label="open drawer"
              edge="start"
              onClick={handleDrawerToggle}
              sx={{ mr: 2, display: { md: "none" } }}
            >
              <MenuIcon />
            </IconButton>
            <Typography variant="h6" noWrap component="div"></Typography>
          </Box>
          <Box display={"flex"} alignItems={"center"} gap={1}>
            <Box
              display={"flex"}
              alignItems={"center"}
              gap={1}
              sx={{
                background: "var(--clr_gray_100)",
                padding: "8px",
                borderRadius: "30px",
              }}
            >
              <Avatar
                sx={{
                  width: 34,
                  height: 34,
                  cursor: "pointer",
                  background: "var(--primary_light)",
                  color: "var(--primary_Active_text)",
                  fontSize: "0.8rem",
                }}
                alt="Remy Sharp"
                src="/static/images/avatar/1.jpg"
              />
              <IconButton aria-label="log out" size="medium" color="error">
                <LogoutIcon fontSize="small" onClick={logoutHandler} />
              </IconButton>
            </Box>
          </Box>
        </Toolbar>
      </CssAppBar>

      <Box
        component="nav"
        sx={{ width: { md: drawerWidth }, flexShrink: { md: 0 } }}
        aria-label="mailbox folders"
      >
        <Drawer
          container={container}
          variant="temporary"
          open={mobileOpen}
          onTransitionEnd={handleDrawerTransitionEnd}
          onClose={handleDrawerClose}
          ModalProps={{
            keepMounted: true, // Better open performance on mobile.
          }}
          sx={{
            display: { xs: "block", md: "none" },
            "& .MuiDrawer-paper": {
              boxSizing: "border-box",
              width: drawerWidth,
            },
          }}
        >
          {drawer}
        </Drawer>
        <Drawer
          variant="permanent"
          sx={{
            display: { xs: "none", md: "block" },
            "& .MuiDrawer-paper": {
              boxSizing: "border-box",
              width: drawerWidth,
            },
          }}
          open
        >
          {drawer}
        </Drawer>
      </Box>
      <Box
        component="main"
        sx={{
          flexGrow: 1,
          p: 3,
          width: { xs: "100%", md: `calc(100% - ${drawerWidth}px)` },
        }}
      >
        <Toolbar />
        {Children}
      </Box>
    </Box>
  );
}
